==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>Vezeték nélküli hálózat bekapcsolva</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>Vezeték nélküli hálózat kikapcsolva</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock bekapcsolva</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock kikapcsolva</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Számbillentyűzet bekapcsolva</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Számbillentyűzet kikapcsolva</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Érintőpad bekapcsolva</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Érintőpad kikapcsolva</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Érintőpad gombok</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Funkció kapcsoló</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Repülőgép üzemmód bekapcsolva</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Repülőgép üzemmód kikapcsolva</translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Némítás bekapcsolva</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Némítás kikapcsolva</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Kiegyensúlyozott teljesítmény</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Energiatakarékos mód</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Magas teljesítmény </translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Az ablakeffektusok engedélyezve</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Az ablakeffektusok letiltva</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Az ablakeffektusok engedélyezése sikertelen</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.3.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>Vezeték nélküli hálózat bekapcsolva</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>Vezeték nélküli hálózat kikapcsolva</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock bekapcsolva</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock kikapcsolva</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Számbillentyűzet bekapcsolva</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Számbillentyűzet kikapcsolva</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Érintőpad bekapcsolva</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Érintőpad kikapcsolva</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Érintőpad gombok</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Funkció kapcsoló</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Repülőgép üzemmód bekapcsolva</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Repülőgép üzemmód kikapcsolva</translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Némítás bekapcsolva</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Némítás kikapcsolva</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Kiegyensúlyozott teljesítmény</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Energiatakarékos mód</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Magas teljesítmény </translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Az ablakeffektusok engedélyezve</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Az ablakeffektusok letiltva</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Az ablakeffektusok engedélyezése sikertelen</translation>
    </message>
</context>
</TS>
